SecretColors
========================================
It is a python `library <https://pypi.org/project/SecretColors/>`_ for fantastic
color palettes. You can read more about it from its GitHub `website
<https://github.com/secretBiology/SecretColors>`_. It can be installed via
following PyPi distribution

.. code-block:: console

    pip install SecretColors

This document contains full API reference of the library. There are few
private functions which are not included here can be accessed directly via
source code on `GitHub <https://github.com/secretBiology/SecretColors>`_.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

    API Reference <api.rst>



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

